@@ -1,9 +1,11 @@
 /*
- * Blue Engine copyright 2021 © Elham Aryanpur
+ * Blue Engine by Elham Aryanpur
  *
  * The license is same as the one on the root.
 */
 
+extern crate nalgebra_glm as glm;
+
 pub(crate) mod definition;
 pub mod header;
 pub mod objects;
