@@ -1,10 +1,13 @@
 /*
- * Blue Engine copyright © Elham Aryanpur
+ * Blue Engine by Elham Aryanpur
  *
  * The license is same as the one on the root.
 */
 
-use crate::header::{Camera, Engine, Object, Renderer, TextureData, UniformBuffer, WindowDescriptor, uniform_type};
+use crate::header::{
+    uniform_type, Camera, Engine, Object, Renderer, ShaderSettings, TextureData, UniformBuffer,
+    WindowDescriptor,
+};
 use crate::utils::default_resources::{
     DEFAULT_COLOR, DEFAULT_MATRIX_4, DEFAULT_SHADER, DEFAULT_TEXTURE,
 };
@@ -63,10 +66,7 @@ impl Engine {
 
         let default_uniform = renderer
             .build_and_append_uniform_buffers(vec![
-                UniformBuffer::Matrix(
-                    "Transformation Matrix",
-                    uniform_type::Matrix::from_glm(DEFAULT_MATRIX_4),
-                ),
+                UniformBuffer::Matrix("Transformation Matrix", DEFAULT_MATRIX_4),
                 UniformBuffer::Array(
                     "Color",
                     uniform_type::Array {
@@ -80,6 +80,7 @@ impl Engine {
             "Default Shader",
             DEFAULT_SHADER.to_string(),
             Some(&default_uniform),
+            ShaderSettings::default(),
         )?;
 
         Ok(Self {
